@@ -58,7 +58,6 @@ from testwizard.commands_web.SwitchToWindowCommand import SwitchToWindow
 from testwizard.commands_web.WaitForControlCommand import WaitForControl
 
 #Video commands
-from testwizard.commands_video import GetVideoFormatCommand
 from testwizard.commands_video import GetVideoResolutionCommand
 from testwizard.commands_video import CompareCommand
 from testwizard.commands_video import CountLastPatternMatchesCommand
@@ -81,6 +80,7 @@ from testwizard.commands_video import DetectNoMotionCommand
 from testwizard.commands_video import LoadReferenceBitmapCommand
 from testwizard.commands_video import SaveReferenceBitmapCommand
 from testwizard.commands_video import SaveRegionCommand
+from testwizard.commands_video import SnapShotCommand
 from testwizard.commands_video import SnapShotBMPCommand
 from testwizard.commands_video import SnapShotJPGCommand
 from testwizard.commands_video import StartBackgroundCaptureCommand
@@ -298,10 +298,6 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return CaptureReferenceBitmapCommand(self).execute()
     
-    def getVideoFormat(self):
-        self.throwIfDisposed()
-        return GetVideoFormatCommand(self).execute()
-    
     def getVideoResolution(self):
         self.throwIfDisposed()
         return GetVideoResolutionCommand(self).execute()
@@ -386,6 +382,10 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return SaveRegionCommand(self).execute(filename)
     
+    def snapShot(self, filename, imageFormat, quality):
+        self.throwIfDisposed()
+        return SnapShotCommand(self).execute(filename, imageFormat, quality)
+
     def snapShotBMP(self, filename):
         self.throwIfDisposed()
         return SnapShotBMPCommand(self).execute(filename)
